# -*- coding: utf-8 -*-
"""Time intervals in Bitfinex."""
from typing import List

intervals: List[str] = [
    '1m',
    '5m',
    '15m',
    '30m',
    '1h',
    '3h',
    '6h',
    '12h',
    '1D',
    '7D',
    '14D',
    '1M',
]
